Enum CoderResult
enum CoderResult
Result of a (potentially partial) decode or encode operation with replacement.
Variants
-
InputEmpty The input was exhausted.
If this result was returned from a call where
lastwastrue, the conversion process has completed. Otherwise, the caller should call a decode or encode method again with more input.-
OutputFull The converter cannot produce another unit of output, because the output buffer does not have enough space left.
The caller must provide more output space upon the next call and re-push the remaining input to the converter.
Implementations
impl Debug for CoderResult
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for CoderResult
impl Freeze for CoderResult
impl PartialEq for CoderResult
fn eq(self: &Self, other: &CoderResult) -> bool
impl RefUnwindSafe for CoderResult
impl Send for CoderResult
impl StructuralPartialEq for CoderResult
impl Sync for CoderResult
impl Unpin for CoderResult
impl UnsafeUnpin for CoderResult
impl UnwindSafe for CoderResult
impl<T> Any for CoderResult
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for CoderResult
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for CoderResult
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for CoderResult
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for CoderResult
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for CoderResult
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for CoderResult
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>